# Why funkyprompt?

`funkyprompt` is a functionally orientated way to make prompts for speaking with LLMs. As LLMs and building applications such as Retrieval Augmented Generation (RAG) systems have exploded in activity, the ecosystem and tooling is evolving incredibly quickly. `funkyprompt` takes a disciplined approach to constructing applications with more or multiple agents by adhering to existing programming patterns, particularly functional ones to construct applications.

Rather than build entirely new types of applications the idea is to point LLMs at your existing code based (or new code based design for Agent systems but written the way you normally would) to build programs and reason about program flow and construction.

## Install

```bash
pip install funkyprompt
```

Or you can clone the project and do the poetry stuff..

```bash
poetry install funkyprompt

```
